==> igniteui-angular-charts-18.2.0.tgz: package/esm2015/lib/igx-itemwise-strategy-based-indicator-component.js <==
import { Component } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import * as i0 from "@angular/core";
/**
 * Financial indicator base class for doing calculating an itemwize indicator.
 * An itemwise indicator's individual values don't depend on any other values in the
 * collection so can always be independently recalculated. Also, because of this, the
 * base class handles all the looping logic and inheritors only need to provide the
 * actual calculation.
*/
export let IgxItemwiseStrategyBasedIndicatorComponent = /*@__PURE__*/ (() => {
    class IgxItemwiseStrategyBasedIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
        constructor() {
            super();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        /**
         * This is a marker method to distinguish this from a public api perspective on some platforms compared to the base strategy based indicators.
        
        */
        resolveIsItemwise() {
            let iv = this.i.aci();
            return (iv);
        }
    }
    IgxItemwiseStrategyBasedIndicatorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxItemwiseStrategyBasedIndicatorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxItemwiseStrategyBasedIndicatorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxItemwiseStrategyBasedIndicatorComponent, selector: "ng-component", usesInheritance: true, ngImport: i0, template: ``, isInline: true });
    return IgxItemwiseStrategyBasedIndicatorComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxItemwiseStrategyBasedIndicatorComponent, decorators: [{
            type: Component,
            args: [{
                    template: ``,
                }]
        }], ctorParameters: function () { return []; } });

==> igniteui-angular-charts-20.0.0.tgz: package/esm2015/lib/igx-itemwise-strategy-based-indicator-component.js <==
import { Component } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import * as i0 from "@angular/core";
/**
 * Financial indicator base class for doing calculating an itemwize indicator.
 * An itemwise indicator's individual values don't depend on any other values in the
 * collection so can always be independently recalculated. Also, because of this, the
 * base class handles all the looping logic and inheritors only need to provide the
 * actual calculation.
*/
export let IgxItemwiseStrategyBasedIndicatorComponent = /*@__PURE__*/ (() => {
    class IgxItemwiseStrategyBasedIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
        constructor() {
            super();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        /**
         * This is a marker method to distinguish this from a public api perspective on some platforms compared to the base strategy based indicators.
        
        */
        resolveIsItemwise() {
            let iv = this.i.acn();
            return (iv);
        }
    }
    IgxItemwiseStrategyBasedIndicatorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxItemwiseStrategyBasedIndicatorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxItemwiseStrategyBasedIndicatorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxItemwiseStrategyBasedIndicatorComponent, selector: "ng-component", usesInheritance: true, ngImport: i0, template: ``, isInline: true });
    return IgxItemwiseStrategyBasedIndicatorComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxItemwiseStrategyBasedIndicatorComponent, decorators: [{
            type: Component,
            args: [{
                    template: ``,
                }]
        }], ctorParameters: function () { return []; } });
